@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '5.20200820';
+$CPAN::Perl::Releases::VERSION = '5.20210220';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -265,6 +265,14 @@ our $data =
 "5.32.0" => { id => 'XSAWYERX' },
 "5.33.0" => { id => 'XSAWYERX' },
 "5.33.1" => { id => 'ETHER' },
+"5.33.2" => { id => 'XSAWYERX' },
+"5.33.3" => { id => 'SHAY' },
+"5.33.4" => { id => 'TOMHUKINS' },
+"5.33.5" => { id => 'CORION' },
+"5.32.1-RC1" => { id => 'SHAY' },
+"5.33.6" => { id => 'HYDAHY' },
+"5.32.1" => { id => 'SHAY' },
+"5.33.7" => { id => 'RENEEB' },
 };
 
 sub perl_tarballs {
@@ -333,7 +341,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 5.20200820
+version 5.20210220
 
 =head1 SYNOPSIS
 
@@ -398,7 +406,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Chris Williams.
+This software is copyright (c) 2021 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
